==> stream_chat-0.1.16.tar.gz: lib/src/models/own_user.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'device.dart';
import 'mute.dart';
import 'serialization.dart';
import 'user.dart';

part 'own_user.g.dart';

/// The class that defines the own user model
/// This object can be found in [Event]
@JsonSerializable()
class OwnUser extends User {
  /// List of user devices
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final List<Device> devices;

  /// List of users muted by the user
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final List<Mute> mutes;

  /// Total unread messages by the user
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final int totalUnreadCount;

  /// Total unread channels by the user
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final int unreadChannels;

  /// Known top level fields.
  /// Useful for [Serialization] methods.
  static final topLevelFields = [
    'devices',
    'mutes',
    'total_unread_count',
    'unread_channels',
  ]..addAll(User.topLevelFields);

  /// Constructor used for json serialization
  OwnUser({
    this.devices,
    this.mutes,
    this.totalUnreadCount,
    this.unreadChannels,
    String id,
    String role,
    DateTime createdAt,
    DateTime updatedAt,
    DateTime lastActive,
    bool online,
    Map<String, dynamic> extraData,
    bool banned,
  }) : super(
          id: id,
          role: role,
          createdAt: createdAt,
          updatedAt: updatedAt,
          lastActive: lastActive,
          online: online,
          extraData: extraData,
          banned: banned,
        );

  /// Create a new instance from a json
  factory OwnUser.fromJson(Map<String, dynamic> json) {
    return _$OwnUserFromJson(
        Serialization.moveKeysToRoot(json, topLevelFields));
  }

  /// Serialize to json
  Map<String, dynamic> toJson() {
    return Serialization.moveKeysToMapInPlace(
        _$OwnUserToJson(this), topLevelFields);
  }
}

==> stream_chat-1.5.2.tar.gz: lib/src/models/own_user.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:stream_chat/src/models/device.dart';
import 'package:stream_chat/src/models/mute.dart';
import 'package:stream_chat/src/models/serialization.dart';
import 'package:stream_chat/src/models/user.dart';

part 'own_user.g.dart';

/// The class that defines the own user model
/// This object can be found in [Event]
@JsonSerializable()
class OwnUser extends User {
  /// Constructor used for json serialization
  OwnUser({
    this.devices,
    this.mutes,
    this.totalUnreadCount,
    this.unreadChannels,
    this.channelMutes,
    String id,
    String role,
    DateTime createdAt,
    DateTime updatedAt,
    DateTime lastActive,
    bool online,
    Map<String, dynamic> extraData,
    bool banned,
  }) : super(
          id: id,
          role: role,
          createdAt: createdAt,
          updatedAt: updatedAt,
          lastActive: lastActive,
          online: online,
          extraData: extraData,
          banned: banned,
        );

  /// Create a new instance from a json
  factory OwnUser.fromJson(Map<String, dynamic> json) => _$OwnUserFromJson(
      Serialization.moveToExtraDataFromRoot(json, topLevelFields));

  /// List of user devices
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final List<Device> devices;

  /// List of users muted by the user
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final List<Mute> mutes;

  /// List of users muted by the user
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final List<Mute> channelMutes;

  /// Total unread messages by the user
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final int totalUnreadCount;

  /// Total unread channels by the user
  @JsonKey(includeIfNull: false, toJson: Serialization.readOnly)
  final int unreadChannels;

  /// Known top level fields.
  /// Useful for [Serialization] methods.
  static final topLevelFields = [
    'devices',
    'mutes',
    'total_unread_count',
    'unread_channels',
    'channel_mutes',
    ...User.topLevelFields,
  ];

  /// Serialize to json
  @override
  Map<String, dynamic> toJson() => Serialization.moveFromExtraDataToRoot(
      _$OwnUserToJson(this), topLevelFields);
}
